DcontextLayerBuilder

Struct DcontextLayerBuilder 

pub struct DcontextLayerBuilder<S> { /* private fields */ }
Builder for configuring a DcontextLayer.

Implementations

Source

impl<S> DcontextLayerBuilder<S>

pub fn map_field<T: FromFieldValue>(self, field_name: &'static str) -> Self

Map a tracing span field to a dcontext key.

When a span containing a field with the given name is entered, the field value is extracted and set as a dcontext value of type T.

The field name is used as both the tracing field name and the dcontext key.

Type Requirements

T must implement FromFieldValue for conversion from tracing field values to the context type.

pub fn map_field_as<T: FromFieldValue>( self, field_name: &'static str, context_key: &'static str, ) -> Self

Map a tracing span field to a dcontext key with a different key name.

Similar to map_field but allows using a different name for the dcontext key than the tracing field name.

pub fn include_span_info(self) -> Self

Include span metadata (name, target, level) as a SpanInfo context value.

When enabled, each span enter will set a SpanInfo value under the key "dcontext.span".

pub fn build(self) -> DcontextLayer<S>

Build the configured DcontextLayer.